# config file for ansible -- https://ansible.com/
# ===============================================
[defaults]

# some basic default values...
forks          = 5
transport      = smart

# additional paths to search for roles in, colon separated
roles_path = {{ roles_path }}

# uncomment this to disable SSH key host checking
host_key_checking = False

# SSH timeout
timeout = 60

# logging is off by default unless this path is defined
# if so defined, consider logrotate
log_path = /var/log/ansible.log

# Ansible managed string
ansible_managed = #########                     #########
                  ### This file is managed by Ansible ###
                  ###           ###########           ###
                  ### All changes will be overwritten ###
                  #########                     #########

# Retry files
retry_files_enabled = False
retry_files_save_path = ~/.ansible-retry

# This keeps facts from polluting the main namespace as variables.
# Setting to True keeps them under the ansible_facts namespace, the default is False
#restrict_facts_namespace: True


[ssh_connection]
ssh_args = -C -o ControlMaster=auto -o ControlPersist=60s

# The base directory for the ControlPath sockets.
# This is the "%(directory)s" in the control_path option
control_path_dir = ~/.ansible/cp
control_path = %(directory)s/ansible-ssh-%%h-%%p-%%r

# Enabling pipelining reduces the number of SSH operations required to
# execute a module on the remote server.
pipelining = True